@@ -17,7 +17,10 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-optics <- function(x, eps, minPts = 5, ...) {
+optics <- function(x, eps = NULL, minPts = 5, ...) {
+
+  ### find eps from minPts
+  if(is.null(eps)) eps <- max(kNNdist(x, k =  minPts)[,minPts])
 
   ### extra contains settings for frNN
   ### search = "kdtree", bucketSize = 10, splitRule = "suggest", approx = 0
